@@ -1,12 +1,17 @@
 #![no_std]
 #![cfg_attr(docsrs, feature(doc_cfg))]
-#![warn(missing_docs, rust_2018_idioms)]
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
-    html_root_url = "https://docs.rs/base64ct/1.3.3"
+    html_root_url = "https://docs.rs/base64ct/1.4.0"
 )]
 #![doc = include_str!("../README.md")]
+#![warn(
+    missing_docs,
+    rust_2018_idioms,
+    unused_lifetimes,
+    unused_qualifications
+)]
 
 //! # Usage
 //!
@@ -47,7 +52,7 @@
 //!
 //! # Implementation
 //!
-//! Implemented using bitwise arithmetic alone without any lookup tables or
+//! Implemented using integer arithmetic alone without any lookup tables or
 //! data-dependent branches, thereby providing portable "best effort"
 //! constant-time operation.
 //!
@@ -59,9 +64,6 @@
 //!
 //! Copyright (c) 2014 Steve "Sc00bz" Thomas (steve at tobtu dot com).
 //! Derived code is dual licensed MIT + Apache 2 (with permission from Sc00bz).
-//!
-//! [RFC 4648, section 4]: https://tools.ietf.org/html/rfc4648#section-4
-//! [Util::Lookup]: https://arxiv.org/pdf/2108.04600.pdf
 
 #[cfg(feature = "alloc")]
 #[macro_use]
@@ -70,14 +72,21 @@ extern crate alloc;
 extern crate std;
 
 mod decoder;
+mod encoder;
 mod encoding;
 mod errors;
+mod line_ending;
 mod variant;
 
+#[cfg(test)]
+mod test_vectors;
+
 pub use crate::{
     decoder::Decoder,
+    encoder::Encoder,
     encoding::Encoding,
     errors::{Error, InvalidEncodingError, InvalidLengthError},
+    line_ending::LineEnding,
     variant::{
         bcrypt::Base64Bcrypt,
         crypt::Base64Crypt,
@@ -85,3 +94,6 @@ pub use crate::{
         url::{Base64Url, Base64UrlUnpadded},
     },
 };
+
+/// Minimum supported line width.
+const MIN_LINE_WIDTH: usize = 4;
